OC.L10N.register(
    "files",
    {
    "File could not be found" : "Datei konnte nicht gefunden werden",
    "Move or copy" : "Verschieben oder kopieren",
    "Download" : "Herunterladen",
    "Delete" : "Löschen",
    "Tags" : "Schlagworte",
    "Show list view" : "Listenansicht anzeigen",
    "Show grid view" : "Kachelansicht anzeigen",
    "Home" : "Home",
    "Close" : "Schließen",
    "Could not create folder \"{dir}\"" : "Der Ordner konnte nicht erstellt werden \"{dir}\"",
    "This will stop your current uploads." : "Hiermit werden die aktuellen Uploads angehalten.",
    "Upload cancelled." : "Hochladen abgebrochen.",
    "Processing files …" : "Dateien werden verarbeitet…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Die Datei {filename} kann nicht hochgeladen werden, da sie entweder ein Verzeichnis oder 0 Bytes groß ist",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nicht genügend freier Speicherplatz, Sie möchten {size1} hochladen, es sind jedoch nur noch {size2} verfügbar.",
    "Target folder \"{dir}\" does not exist any more" : "Ziel-Verzeichnis \"{dir}\" existiert nicht mehr",
    "Not enough free space" : "Nicht genügend freier Speicherplatz",
    "An unknown error has occurred" : "Es ist ein unbekannter Fehler aufgetreten",
    "File could not be uploaded" : "Datei konnte nicht hochgeladen werden",
    "Uploading …" : "Lade hoch …",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "Lade hoch… ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} von {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Hochladen von Daten dieser Art wird nicht unterstützt.",
    "Target folder does not exist any more" : "Zielordner existiert nicht mehr",
    "Operation is blocked by access control" : "Vorgang wird durch die Zugangskontrolle blockiert",
    "Error when assembling chunks, status code {status}" : "Fehler beim Zusammenführen der Teile (Chunks), Fehlermeldung {status}",
    "Actions" : "Aktionen",
    "Rename" : "Umbenennen",
    "Move" : "Verschieben",
    "Copy" : "Kopieren",
    "Choose target folder" : "Zielordner auswählen",
    "Set reminder" : "Erinnerung erstellen",
    "Edit locally" : "Lokal bearbeiten",
    "Open" : "Öffnen",
    "Delete file" : "Datei löschen",
    "Delete folder" : "Ordner löschen",
    "Disconnect storage" : "Speicher trennen",
    "Leave this share" : "Diese Freigabe verlassen",
    "Could not load info for file \"{file}\"" : "Die Informationen zur Datei \"{file}\" konnten nicht geladen werden",
    "Files" : "Dateien",
    "Details" : "Details",
    "Please select tag(s) to add to the selection" : "Bitte wählen Sie das/die Schlagwort(e) aus, das/die Sie zur Auswahl hinzufügen möchten",
    "Apply tag(s) to selection" : "Schlagwort(e) auf die Auswahl anwenden",
    "Select directory \"{dirName}\"" : "Ordner \"{dirName}\" auswählen",
    "Select file \"{fileName}\"" : "Datei \"{fileName}\" auswählen",
    "Pending" : "Ausstehend",
    "Unable to determine date" : "Datum konnte nicht ermittelt werden",
    "This operation is forbidden" : "Diese Operation ist nicht erlaubt",
    "This directory is unavailable, please check the logs or contact the administrator" : "Dieses Verzeichnis ist nicht verfügbar, bitte überprüfen Sie die Protokolldateien oder kontaktieren Sie die Administration",
    "Storage is temporarily not available" : "Speicher ist vorübergehend nicht verfügbar",
    "Could not move \"{file}\", target exists" : "\"{file}\" konnte nicht verschoben werden, Ziel existiert bereits",
    "Could not move \"{file}\"" : "\"{file}\" konnte nicht verschoben werden",
    "copy" : "Kopie",
    "Could not copy \"{file}\", target exists" : "\"{file}\" konnte nicht kopiert werden, Ziel existiert bereits",
    "Could not copy \"{file}\"" : "\"{file}\" konnte nicht kopiert werden",
    "Copied {origin} inside {destination}" : "{origin} wurde nach {destination} kopiert",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} und {nbfiles} weitere Dateien wurden nach {destination} kopiert",
    "Failed to redirect to client" : "Umleitung zum Client fehlgeschlagen",
    "{newName} already exists" : "{newName} existiert bereits",
    "Could not rename \"{fileName}\", it does not exist any more" : "Die Datei \"{fileName}\" konnte nicht umbenannt werden, da sie nicht mehr existiert",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name „{targetName}“ wird bereits im Ordner „{dir}“ benutzt. Bitte wählen Sie einen anderen Namen.",
    "Could not rename \"{fileName}\"" : "Die Datei konnte nicht umbenannt werden \"{fileName}\"",
    "Could not create file \"{file}\"" : "Die Datei konnte nicht erstellt werden \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Die Datei \"{file}\" konnte nicht erstellt werden, da diese bereits existiert",
    "Could not create folder \"{dir}\" because it already exists" : "Der Ordner \"{dir}\" konnte nicht erstellt werden, da dieser bereits existiert",
    "Could not fetch file details \"{file}\"" : "Details zu \"{file}\" konnten nicht ermittelt werden",
    "Error deleting file \"{fileName}\"." : "Fehler beim Löschen der Datei \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Keine Suchergebnisse in anderen Ordnern für {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Geben Sie mehr als zwei Zeichen ein, um in anderen Ordnern zu suchen",
    "Name" : "Name",
    "Size" : "Größe",
    "Modified" : "Geändert",
    "_%n folder_::_%n folders_" : ["%n Ordner","%n Ordner"],
    "_%n file_::_%n files_" : ["%n Datei","%n Dateien"],
    "{dirs} and {files}" : "{dirs} und {files}",
    "_including %n hidden_::_including %n hidden_" : ["%n versteckte eingeschlossen","%n versteckte eingeschlossen"],
    "You do not have permission to upload or create files here" : "Sie haben keine Berechtigung, hier Dateien hochzuladen oder zu erstellen",
    "_Uploading %n file_::_Uploading %n files_" : ["%n Datei wird hoch geladen","%n Dateien werden hochgeladen"],
    "New" : "Neu",
    "New file/folder menu" : "Menü für neue Datei/Ordner",
    "Select file range" : "Dateibereich auswählen",
    "{used}%" : "{used}%",
    "{used} of {quota} used" : "{used} von {quota} verwendet",
    "{used} used" : "{used} verwendet",
    "\"{name}\" is an invalid file name." : "„{name}“ ist kein gültiger Dateiname.",
    "File name cannot be empty." : "Der Dateiname darf nicht leer sein.",
    "\"/\" is not allowed inside a file name." : "\"/\" ist innerhalb eines Dateinamens nicht erlaubt.",
    "\"{name}\" is not an allowed filetype" : "„{name}“ ist kein erlaubter Dateityp",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Der Speicher von {owner} ist voll, Dateien können nicht mehr aktualisiert oder synchronisiert werden!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Gruppenordner \"{mountPoint}\" ist voll, Dateien können nicht mehr aktualisiert oder synchronisiert werden!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Externer Speicher \"{mountPoint}\" ist voll, Dateien können nicht mehr aktualisiert oder synchronisiert werden!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Ihr Speicher ist voll, daher können keine Dateien mehr aktualisiert oder synchronisiert werden!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Der Speicher von {owner} ist beinahe voll ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Gruppenordner \"{mountPoint}\" ist beinahe voll ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Externer Speicher \"{mountPoint}\" ist beinahe voll ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Ihr Speicher ist beinahe voll ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["stimmt mit \"{filter}\" überein","stimmen mit \"{filter}\" überein"],
    "View in folder" : "In Ordner anzeigen",
    "Direct link was copied (only works for people who have access to this file/folder)" : "Direktlink wurde kopiert (funktioniert nur für Personen, die Zugriff auf diese Datei/Ordner haben)",
    "Path" : "Pfad",
    "_%n byte_::_%n bytes_" : ["%n Byte","%n Bytes"],
    "Favorited" : "Favorisiert",
    "Favorite" : "Favorit",
    "Copy direct link (only works for people who have access to this file/folder)" : "Direkten Link kopieren (funktioniert nur für Personen, die Zugriff auf diese Datei bzw. den Ordner haben)",
    "New folder" : "Neuer Ordner",
    "Create new folder" : "Neuen Ordner erstellen",
    "Upload file" : "Datei hochladen",
    "Recent" : "Neueste",
    "Not favorited" : "Nicht favorisiert",
    "Remove from favorites" : "Von Favoriten entfernen",
    "Add to favorites" : "Zu den Favoriten hinzufügen",
    "An error occurred while trying to update the tags" : "Es ist ein Fehler beim Aktualisieren der Schlagworte aufgetreten",
    "Added to favorites" : "Zu den Favoriten hinzugefügt",
    "Removed from favorites" : "Aus den Favoriten entfernt",
    "You added {file} to your favorites" : "Sie haben {file} zu Ihren Favoriten hinzugefügt",
    "You removed {file} from your favorites" : "Sie haben {file} aus Ihren Favoriten entfernt",
    "Favorites" : "Favoriten",
    "File changes" : "Dateiänderungen",
    "Created by {user}" : "Erstellt durch {user}",
    "Changed by {user}" : "Geändert durch {user}",
    "Deleted by {user}" : "Gelöscht durch {user}",
    "Restored by {user}" : "Wiederhergestellt durch {user}",
    "Renamed by {user}" : "Umbenannt durch {user}",
    "Moved by {user}" : "Verschoben durch {user}",
    "\"remote account\"" : "\"Entferntes Konto\"",
    "You created {file}" : "Sie haben {file} erstellt",
    "You created an encrypted file in {file}" : "Sie haben eine verschlüsselte Datei in {file} erstellt",
    "{user} created {file}" : "{user} hat {file} erstellt",
    "{user} created an encrypted file in {file}" : "{user} hat eine verschlüsselte Datei in {file} erstellt",
    "{file} was created in a public folder" : "{file} wurde in einem öffentlichen Ordner erstellt",
    "You changed {file}" : "Sie haben {file} geändert",
    "You changed an encrypted file in {file}" : "Sie haben eine verschlüsselte Datei in {file} geändert",
    "{user} changed {file}" : "{user} hat {file} geändert",
    "{user} changed an encrypted file in {file}" : "{user} hat eine verschlüsselte Datei in {file} geändert",
    "You deleted {file}" : "Sie haben {file} gelöscht",
    "You deleted an encrypted file in {file}" : "Sie haben eine verschlüsselte Datei in {file} gelöscht",
    "{user} deleted {file}" : "{user} hat {file} gelöscht",
    "{user} deleted an encrypted file in {file}" : "{user} hat eine verschlüsselte Datei in {file} gelöscht",
    "You restored {file}" : "Sie haben {file} wiederhergestellt",
    "{user} restored {file}" : "{user} hat {file} wiederhergestellt",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Sie haben {oldfile} (versteckt) in {newfile} (versteckt) umbenannt",
    "You renamed {oldfile} (hidden) to {newfile}" : "Sie haben {oldfile} (versteckt) in {newfile} umbenannt",
    "You renamed {oldfile} to {newfile} (hidden)" : "Sie haben {oldfile} in {newfile} (versteckt) umbenannt",
    "You renamed {oldfile} to {newfile}" : "Sie haben {oldfile} in {newfile} umbenannt",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} hat {oldfile} (versteckt) in {newfile} (versteckt) umbenannt",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} hat {oldfile} (versteckt) in {newfile} umbenannt",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} hat {oldfile} in {newfile} (versteckt) umbenannt",
    "{user} renamed {oldfile} to {newfile}" : "{user} hat {oldfile} in {newfile} umbenannt",
    "You moved {oldfile} to {newfile}" : "Sie haben {oldfile} nach {newfile} verschoben",
    "{user} moved {oldfile} to {newfile}" : "{user} hat {oldfile} nach {newfile} verschoben",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Eine Datei wurde Ihren <strong>Favoriten</strong> hinzugefügt oder daraus entfernt",
    "A file or folder has been <strong>changed</strong>" : "Eine Datei oder ein Ordner wurde <strong>geändert</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Eine favorisierte Datei oder ein Ordner wurde <strong>geändert</strong>",
    "Upload (max. %s)" : "Hochladen (max. %s)",
    "Accept" : "Akzeptieren",
    "Reject" : "Ablehnen",
    "Incoming ownership transfer from {user}" : "Eingehende Besitzübertragung von {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Soll {path} angenommen werden?\n\nInfo: Der Übertragungsprozess nach der Annahme kann bis zu einer Stunde dauern.",
    "Ownership transfer failed" : "Besitzübertragung fehlgeschlagen",
    "Your ownership transfer of {path} to {user} failed." : "Die Besitzübertragung von {path} an {user} ist fehlgeschlagen.",
    "The ownership transfer of {path} from {user} failed." : "Die Besitzübertragung von {path} vom Benutzer {user} ist fehlgeschlagen.",
    "Ownership transfer done" : "Besitzübertragung abgeschlossen",
    "Your ownership transfer of {path} to {user} has completed." : "Die Besitzübertragung von {path} an {user} wurde fertiggestellt.",
    "The ownership transfer of {path} from {user} has completed." : "Die Besitzübertragung von {path} durch {user} wurde fertiggestellt.",
    "in %s" : "in %s",
    "File Management" : "Dateiverwaltung",
    "Current directory path" : "Aktueller Verzeichnispfad",
    "Reload current directory" : "Aktuelles Verzeichnis neu laden",
    "Go to the \"{dir}\" directory" : "In das Verzeichnis \"{dir}“ wechseln",
    "Drag and drop files here to upload" : "Dateien zum Hochladen hierher ziehen und ablegen",
    "Your have used your space quota and cannot upload files anymore" : "Ihr Speicherplatzkontigent ist aufgebraucht, Sie können keine weiteren Dateien hochladen",
    "You don’t have permission to upload or create files here" : "Sie haben keine Berechtigung, hier Dateien hochzuladen oder zu erstellen",
    "\"{displayName}\" action executed successfully" : "Aktion \"{displayName}\" erfolgreich ausgeführt",
    "\"{displayName}\" action failed" : "Aktion \"{displayName}\" fehlgeschlagen",
    "Toggle selection for file \"{displayName}\"" : "Auswahl für die Datei \"{displayName}\" umschalten",
    "Toggle selection for folder \"{displayName}\"" : "Auswahl für den Ordner \"{displayName}\" umschalten",
    "Rename file" : "Datei umbenennen",
    "File name" : "Dateiname",
    "Folder name" : "Ordnername",
    "This node is unavailable" : "Dieser Knoten ist nicht verfügbar",
    "Download file {name}" : "Datei {name} herunterladen",
    "Invalid file name" : "Ungültiger Dateiname",
    "\"{name}\" is not an allowed filetype." : "\"{name}\" ist kein zulässiger Dateityp.",
    "{newName} already exists." : "{newName} existiert bereits.",
    "\"{char}\" is not allowed inside a file name." : "\"{char}“ ist innerhalb eines Dateinamens nicht zulässig.",
    "Name cannot be empty" : "Der Name darf nicht leer sein",
    "Another entry with the same name already exists" : "Ein anderer Eintrag mit diesem Namen existiert bereits",
    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" in \"{newName}\" umbenannt",
    "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" konnte nicht umbenannt werden, da es nicht mehr existiert",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name \"{newName}“ wird bereits im Ordner \"{dir}“ verwendet. Bitte wählen Sie einen anderen Namen.",
    "Could not rename \"{oldName}\"" : "\"{oldName}\" konnte nicht umbenannt werden",
    "Total rows summary" : "Zusammenfassung aller Zeilen",
    "Toggle selection for all files and folders" : "Auswahl für alle Dateien und Ordner umschalten",
    "\"{displayName}\" failed on some elements " : "\"{displayName}\" ist bei einigen Elementen fehlgeschlagen",
    "\"{displayName}\" batch action executed successfully" : "Stapelaktion \"{displayName}\" erfolgreich ausgeführt",
    "{count} selected" : "{count} ausgewählt",
    "List of files and folders." : "Liste der Dateien und Ordner.",
    "Column headers with buttons are sortable." : "Spaltenüberschriften mit Schaltflächen sind sortierbar.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Diese Liste ist aus Performance-Gründen nicht vollständig gerendert. Die Dateien werden gerendert, wenn Sie durch die Liste navigieren.",
    "File not found" : "Datei nicht gefunden",
    "Storage informations" : "Speicherinformationen",
    "{usedQuotaByte} used" : "{usedQuotaByte} verwendet",
    "{relative}% used" : "{relative}% verwendet",
    "Could not refresh storage stats" : "Die Speicherstatistik konnte nicht aktualisiert werden",
    "Your storage is full, files can not be updated or synced anymore!" : "Ihr Speicher ist voll, daher können keine Dateien mehr aktualisiert oder synchronisiert werden!",
    "Create" : "Erstellen",
    "A file or folder with that name already exists." : "Eine Datei oder ein Ordner mit diesem Namen existiert bereits.",
    "Transfer ownership of a file or folder" : "Besitz einer Datei oder eines Ordners übertragen",
    "Choose file or folder to transfer" : "Datei oder Ordner zur Übertragung auswählen",
    "Change" : "Ändern",
    "New owner" : "Neuer Besitzer",
    "Choose a file or folder to transfer" : "Datei oder Ordner zur Übertragung auswählen",
    "Transfer" : "Übertragen",
    "Transfer {path} to {userid}" : "Übertrage {path} an {userid}",
    "Invalid path selected" : "Ungültiger Pfad ausgewählt",
    "Unknown error" : "Unbekannter Fehler",
    "Ownership transfer request sent" : "Anforderung für die Besitzübertragung versendet",
    "Cannot transfer ownership of a file or folder you do not own" : "Sie können den Besitz von Dateien oder Ordnern, die Sie nicht besitzen, nicht übertragen",
    "Select file or folder to link to" : "Datei oder Ordner zum Verknüpfen auswählen",
    "Choose file" : "Datei auswählen",
    "Choose {file}" : "{file} auswählen",
    "Loading current folder" : "Lade aktuellen Ordner",
    "No files in here" : "Keine Dateien vorhanden",
    "Upload some content or sync with your devices!" : "Laden Sie Inhalte hoch oder synchronisieren Sie Ihre Geräte!",
    "Go to the previous folder" : "Zum vorherigen Ordner wechseln",
    "Go back" : "Zurückgehen",
    "Share" : "Teilen",
    "Shared by link" : "Über einen Link geteilt",
    "Shared" : "Geteilt",
    "Switch to list view" : "Zur Listenansicht wechseln",
    "Switch to grid view" : "Zur Kachelansicht wechseln",
    "Error during upload: {message}" : "Fehler beim Hochladen: {message}",
    "Error during upload, status code {status}" : "Fehler beim Hochladen, Statuscode {status}",
    "Unknown error during upload" : "Unbekannter Fehler beim Hochladen",
    "Open the files app settings" : "Einstellungen der Dateien-App öffnen",
    "Files settings" : "Dateien-Einstellungen",
    "File cannot be accessed" : "Auf die Datei kann nicht zugegriffen werden",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Die Datei konnte nicht gefunden werden oder Sie haben keine Berechtigungen, um sie anzuzeigen. Bitten Sie den Absender, die Datei zu teilen.",
    "Your files" : "Ihre Dateien",
    "Open in files" : "In Dateien öffnen",
    "Sort favorites first" : "Favoriten zuerst sortieren",
    "Sort folders before files" : "Ordner vor Dateien sortieren",
    "Show hidden files" : "Versteckte Dateien anzeigen",
    "Crop image previews" : "Bildvorschauen zuschneiden",
    "Enable the grid view" : "Kachelansicht aktivieren",
    "Additional settings" : "Zusätzliche Einstellungen",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "WebDAV-URL",
    "Copy to clipboard" : "In die Zwischenablage kopieren",
    "Use this address to access your Files via WebDAV" : "Benutzen Sie diese Adresse, um via WebDAV auf Ihre Dateien zuzugreifen",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Wenn Sie 2FA aktiviert haben, müssen Sie ein neues App-Passwort erstellen und verwenden, indem Sie hier klicken.",
    "Clipboard is not available" : "Zwischenablage ist nicht verfügbar",
    "WebDAV URL copied to clipboard" : "WebDAV-URL in die Zwischenablage kopiert",
    "Unable to change the favourite state of the file" : "Der favorisierte Status der Datei kann nicht geändert werden",
    "Error while loading the file data" : "Fehler beim Laden der Datei-Daten",
    "Pick a template for {name}" : "Eine Vorlage für {name} wählen",
    "Create a new file with the selected template" : "Eine neue Datei anhand der ausgewählten Vorlage erstellen",
    "Creating file" : "Datei erstellen",
    "Blank" : "Leer",
    "Unable to create new file from template" : "Neue Datei kann nicht aus Vorlage erstellt werden",
    "Delete permanently" : "Endgültig löschen",
    "Delete and unshare" : "Löschen und nicht mehr teilen",
    "Leave these shares" : "Diese Freigaben verlassen",
    "Disconnect storages" : "Speicher trennen",
    "Delete files" : "Dateien löschen",
    "Delete folders" : "Ordner löschen",
    "You are about to delete {count} items." : "Sie sind dabei, {count} Elemente zu löschen.",
    "Confirm deletion" : "Löschen bestätigen",
    "Cancel" : "Abbrechen",
    "Deletion cancelled" : "Löschen abgebrochen",
    "Destination is not a folder" : "Ziel ist kein Ordner",
    "This file/folder is already in that directory" : "Diese Datei oder Ordner ist bereits in diesem Verzeichnis vorhanden",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Eine Datei oder ein Ordner kann nicht auf sich selbst oder in einen Unterordner von sich selbst verschoben werden",
    "(copy)" : "(kopieren)",
    "(copy %n)" : "(%n kopieren)",
    "Move cancelled" : "Verschieben abgebrochen",
    "A file or folder with that name already exists in this folder" : "In diesem Ordner ist bereits eine Datei oder ein Ordner mit diesem Namen vorhanden",
    "The files are locked" : "Die Dateien sind gesperrt",
    "The file does not exist anymore" : "Diese Datei existiert nicht mehr",
    "Choose destination" : "Ziel wählen",
    "Copy to {target}" : "Nach {target} kopieren",
    "Move to {target}" : "Nach {target} verschieben",
    "Cancelled move or copy operation" : "Verschieben oder kopieren abgebrochen",
    "Move or copy operation failed" : "Verschiebe- oder Kopieroperation ist fehlgeschlagen.",
    "Open folder {displayName}" : "Ordner {displayName} öffnen",
    "Open in Files" : "In Dateien öffnen",
    "Open details" : "Details öffnen",
    "Created new folder \"{name}\"" : "Neuer Ordner \"{name}\" wurde erstellt",
    "Filename" : "Dateiname",
    "Unable to initialize the templates directory" : "Der Vorlagenordner kann nicht initialisiert werden",
    "Create new templates folder" : "Neuen Vorlagenordner erstellen",
    "Templates" : "Vorlagen",
    "New template folder" : "Neuer Vorlagenordner",
    "In folder" : "Im Ordner",
    "Search in folder: {folder}" : "Im Ordner suchen: {folder}",
    "One of the dropped files could not be processed" : "Eine der abgelegten Dateien konnte nicht verarbeitet werden",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Ihr Browser unterstützt die Dateisystem-API nicht. Verzeichnisse werden nicht hochgeladen",
    "No files to upload" : "Keine Dateien zum Hochladen",
    "Unable to create the directory {directory}" : "Der Ordner {directory} konnte nicht erstellt werden",
    "Some files could not be uploaded" : "Einige Dateien konnten nicht hochgeladen werden.",
    "Files uploaded successfully" : "Dateien hochgeladen",
    "No files to process" : "Keine Dateien zum Verarbeiten",
    "Some files could not be copied" : "Einige Dateien konnten nicht kopiert werden",
    "Some files could not be moved" : "Einige Dateien konnten nicht verschoben werden",
    "Files copied successfully" : "Dateien kopiert",
    "Files moved successfully" : "Dateien verschoben",
    "Conflicts resolution skipped" : "Konfliktelösung übersprungen",
    "Upload cancelled" : "Hochladen abgebrochen",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} Ordner","{folderCount} Ordner"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} Datei","{fileCount} Dateien"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 Datei und {folderCount} Ordner","1 Datei und {folderCount} Ordner"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} Datei und 1 Ordner","{fileCount} Dateien und 1 Ordner"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} Dateien und {folderCount} Ordner",
    "List of favorites files and folders." : "Liste der favorisierten Ordner und Dateien.",
    "No favorites yet" : "Noch keine Favoriten vorhanden",
    "Files and folders you mark as favorite will show up here" : "Dateien und Ordner, die Sie als Favoriten kennzeichnen, werden hier erscheinen",
    "All files" : "Alle Dateien",
    "List of your files and folders." : "Liste Ihrer Dateien und Ordner.",
    "Personal Files" : "Persönliche Dateien",
    "List of your files and folders that are not shared." : "Liste Ihrer Dateien und Ordner, die nicht geteilt wurden.",
    "No personal files found" : "Keine persönlichen Dateien gefunden",
    "Files that are not shared will show up here." : "Dateien, die nicht geteilt wurden, werden hier angezeigt.",
    "List of recently modified files and folders." : "Liste der zuletzt geänderten Dateien und Ordner.",
    "No recently modified files" : "Keine kürzlich geänderten Dateien",
    "Files and folders you recently modified will show up here." : "Die von Ihnen kürzlich geänderten Dateien und Ordner werden hier angezeigt.",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
    "Select all" : "Alle auswählen",
    "Upload too large" : "Der Upload ist zu groß",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Die Datei überschreitet die Maximalgröße für Uploads auf diesem Server.",
    "Text file" : "Textdatei",
    "New text file.txt" : "Neue Textdatei file.txt",
    "Direct link was copied (only works for users who have access to this file/folder)" : "Direktlink wurde kopiert (funktioniert nur für Benutzer, die Zugriff auf diese Datei/Ordner haben)",
    "Copy direct link (only works for users who have access to this file/folder)" : "Direkten Link kopieren (funktioniert nur für Benutzer, die Zugriff auf diese(n) Datei/Ordner haben)",
    "You can only favorite a single file or folder at a time" : "Sie können gleichzeitig nur eine Datei oder einen Ordner als Favorit markieren",
    "This file has the tag {tag}" : "Diese Datei trägt das Schlagwort {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Diese Datei trägt die Schlagworte {firstTags} und {lastTag}",
    "\"remote user\"" : "„Externer Benutzer“",
    "Select the row for {displayName}" : "Zeile für {displayName} auswählen",
    "Open folder {name}" : "Ordner {name} öffnen",
    "Unselect all" : "Auswahl aufheben",
    "ascending" : "Aufsteigend",
    "descending" : "Absteigend",
    "Sort list by {column} ({direction})" : "Liste sortieren nach {column} ({direction})",
    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Diese Liste ist aus Performance-Gründen nicht vollständig gerendert. Die Dateien werden gerendert, wenn Sie durch die Liste navigieren.",
    "Search for an account" : "Nach einem Konto suchen",
    "Choose" : "Auswählen",
    "No files or folders have been deleted yet" : "Es wurden noch keine Dateien oder Ordner gelöscht",
    "You might not have have permissions to view it, ask the sender to share it" : "Möglicherweise haben Sie nicht die Berechtigung zur Anzeige. Bitten Sie den Absender, die Datei freizugeben.",
    "Set up templates folder" : "Vorlagenordner einrichten",
    "Toggle %1$s sublist" : "Unterliste %1$s umschalten",
    "Toggle grid view" : "Kachelansicht umschalten",
    "Shares" : "Freigaben",
    "Shared with others" : "Mit anderen geteilt",
    "Shared with you" : "Mit Ihnen geteilt",
    "Deleted shares" : "Gelöschte Freigaben",
    "Pending shares" : "Ausstehende Freigaben",
    "The files is locked" : "Die Datei ist gesperrt"
},
"nplurals=2; plural=(n != 1);");
